OC.L10N.register(
    "calendar",
    {
    "Provided email-address is too long" : "La dirección de correo electrónico proporcionada es demasiado larga",
    "User-Session unexpectedly expired" : "La sesión caducó inesperádamente",
    "Provided email-address is not valid" : "El correo electrónico proporcionado no es válido",
    "%s has published the calendar »%s«" : "%s ha publicado el calendario »%s«",
    "Unexpected error sending email. Please contact your administrator." : "Error inesperado enviando correo. Por favor contacte con el administrador.",
    "Successfully sent email to %1$s" : "Correo enviado correctamente a %1$s",
    "Hello," : "Hola,",
    "We wanted to inform you that %s has published the calendar »%s«." : "Queremos informarle que %s ha publicado el calendario »%s«.",
    "Open »%s«" : "Abrir »%s«",
    "Cheers!" : "¡Saludos!",
    "Upcoming events" : "Próximos eventos",
    "No more events today" : "No hay más eventos hoy",
    "No upcoming events" : "No hay eventos próximos",
    "More events" : "Más eventos",
    "%1$s with %2$s" : "%1$s con %2$s",
    "Calendar" : "Calendario",
    "New booking {booking}" : "Nueva reserva {booking}",
    "{display_name} ({email}) booked the appointment \"{config_display_name}\" on {date_time}." : "{display_name} ({email}) ha reservado la cita \"{config_display_name}\" el {date_time}.",
    "Appointments" : "Citas",
    "Schedule appointment \"%s\"" : "Programar cita \"%s\"",
    "Schedule an appointment" : "Programar una cita",
    "%1$s - %2$s" : "%1$s - %2$s",
    "Prepare for %s" : "Preparación para %s",
    "Follow up for %s" : "Seguimiento para %s",
    "Your appointment \"%s\" with %s needs confirmation" : "Su cita \"%s\" con %s necesita confirmación",
    "Dear %s, please confirm your booking" : "Estimado(a) %s, por favor confirme su reserva",
    "Confirm" : "Confirmar",
    "Appointment with:" : "Cita con:",
    "Description:" : "Descripción:",
    "This confirmation link expires in %s hours." : "Este enlace de confirmación expira en %s horas.",
    "If you wish to cancel the appointment after all, please contact your organizer by replying to this email or by visiting their profile page." : "Si desea cancelar la cita después de todo, contacte al organizador respondiendo a este correo o visitando la página del perfil del mismo.",
    "Your appointment \"%s\" with %s has been accepted" : "Su cita \"%s\" con %s ha sido aceptada",
    "Dear %s, your booking has been accepted." : "Estimado(a) %s, su cita ha sido aceptada.",
    "Appointment for:" : "Cita para:",
    "Date:" : "Fecha:",
    "You will receive a link with the confirmation email" : "Recibirá un enlace con el correo electrónico con de confirmación",
    "Where:" : "Dónde:",
    "Comment:" : "Comentario:",
    "You have a new appointment booking \"%s\" from %s" : "Tiene una cita reservada \"%s\" por %s",
    "Dear %s, %s (%s) booked an appointment with you." : "Estimado(a) %s, %s (%s) ha reservado una cita con Ud.",
    "A Calendar app for Nextcloud" : "Una app de calendario para Nextcloud",
    "Previous day" : "Día anterior",
    "Previous week" : "Semana anterior",
    "Previous year" : "Año anterior",
    "Previous month" : "Mes anterior",
    "Next day" : "Día siguiente",
    "Next week" : "Semana siguiente",
    "Next year" : "Año siguiente",
    "Next month" : "Mes siguiente",
    "Create new event" : "Crear evento nuevo",
    "Event" : "Evento",
    "Today" : "Hoy",
    "Day" : "Día",
    "Week" : "Semana",
    "Month" : "Mes",
    "Year" : "Año",
    "List" : "Lista",
    "Appointment link was copied to clipboard" : "Enlace de la cita copiado al portapapeles",
    "Appointment link could not be copied to clipboard" : "No se ha podido copiar el enlace de la cita al portapapeles",
    "Preview" : "Vista previa",
    "Copy link" : "Copiar enlace",
    "Edit" : "Editar",
    "Delete" : "Eliminar",
    "Appointment schedules" : "Programación de citas",
    "Create new" : "Crear nuevo",
    "Disable calendar \"{calendar}\"" : "Desactivar calendario \"{calendar}\"",
    "Disable untitled calendar" : "Desactivar el calendario sin título",
    "Enable calendar \"{calendar}\"" : "Activar calendario \"{calendar}\"",
    "Enable untitled calendar" : "Activar el calendario sin título",
    "An error occurred, unable to change visibility of the calendar." : "Se ha producido un error, no se ha podido cambiar la visibilidad del calendario.",
    "Untitled calendar" : "Calendario sin título",
    "Shared with you by" : "Compartida con Ud. por",
    "Edit and share calendar" : "Editar y compartir calendario",
    "Edit calendar" : "Editar calendario",
    "_Unsharing the calendar in {countdown} second_::_Unsharing the calendar in {countdown} seconds_" : ["Dejando de compartir el calendario en {countdown} segundo","Dejando de compartir el calendario en {countdown} segundos","Dejando de compartir el calendario en {countdown} segundos"],
    "_Deleting the calendar in {countdown} second_::_Deleting the calendar in {countdown} seconds_" : ["Borrando el calendario en {countdown} segundo","Eliminando el calendario en {countdown} segundos","Eliminando el calendario en {countdown} segundos"],
    "An error occurred, unable to create the calendar." : "Se ha producido un error, no fue posible crear el calendario.",
    "Please enter a valid link (starting with http://, https://, webcal://, or webcals://)" : "Por favor escriba un enlace válido (comenzando con http://, https://, webcal://, o webcals://)",
    "Calendars" : "Calendarios",
    "Add new" : "Añadir nuevo",
    "New calendar" : "Nuevo calendario",
    "Name for new calendar" : "Nombre del nuevo calendario",
    "Creating calendar …" : "Creando calendario…",
    "New calendar with task list" : "Nuevo calendario con lista de tareas",
    "New subscription from link (read-only)" : "Nueva suscripción desde enlace (sólo lectura)",
    "Creating subscription …" : "Creando suscripción…",
    "Add public holiday calendar" : "Añadir calendario de días feriados públicos",
    "Add custom public calendar" : "Añadir calendario público personalizado",
    "Calendar link copied to clipboard." : "Enlace del calendario copiado al portapapeles.",
    "Calendar link could not be copied to clipboard." : "El enlace de calendario no se ha podido copiar al portapapeles. ",
    "Copy subscription link" : "Copiar enlace de suscripción",
    "Copying link …" : "Copiando enlace …",
    "Copied link" : "Enlace copiado",
    "Could not copy link" : "No se ha podido copiar el enlace",
    "Export" : "Exportar",
    "Untitled item" : "Elemento sin nombre",
    "Unknown calendar" : "Calendario desconocido",
    "Could not load deleted calendars and objects" : "No es posible cargar calendarios u objetos eliminados",
    "Could not delete calendar or event" : "No se ha podido eliminar un calendario o un evento",
    "Could not restore calendar or event" : "No es posible restaurar el calendario o evento",
    "Do you really want to empty the trash bin?" : "¿De verdad quieres vaciar la papelera?",
    "Empty trash bin" : "Vaciar papelera",
    "Trash bin" : "Papelera",
    "Loading deleted items." : "Cargando elementos eliminados.",
    "You do not have any deleted items." : "Usted no tiene elementos eliminados.",
    "Name" : "Nombre",
    "Deleted" : "Eliminado",
    "Restore" : "Restaurar",
    "Delete permanently" : "Eliminar permanentemente",
    "_Items in the trash bin are deleted after {numDays} day_::_Items in the trash bin are deleted after {numDays} days_" : ["Los elementos en la papelera de reciclaje se eliminan después de {numDays} día","Los elementos en la papelera de reciclaje se eliminan después de {numDays} días","Los elementos en la papelera de reciclaje se eliminan después de {numDays} días"],
    "Could not update calendar order." : "No se puede actualizar el orden del calendario.",
    "Shared calendars" : "Calendarios compartido",
    "Deck" : "Deck",
    "Hidden" : "Oculto",
    "Internal link" : "Enlace interno",
    "A private link that can be used with external clients" : "Un enlace privado que puede ser utilizado por clientes externos",
    "Copy internal link" : "Copiar enlace interno",
    "An error occurred, unable to publish calendar." : "Se ha producido un error, no se puede publicar el calendario.",
    "An error occurred, unable to send email." : "Se ha producido un error, no se puede enviar el correo.",
    "Embed code copied to clipboard." : "Código incrustado copiado al portapapeles.",
    "Embed code could not be copied to clipboard." : "No se ha podido copiar al portapapeles el código incrustado.",
    "Unpublishing calendar failed" : "Error al cancelar la publicación del calendario",
    "Share link" : "Compartir enlace",
    "Copy public link" : "Copiar enlace público",
    "Send link to calendar via email" : "Enviado enlace al calendario por correo",
    "Enter one address" : "Escriba una dirección",
    "Sending email …" : "Enviando correo…",
    "Copy embedding code" : "Copiar código de insercción",
    "Copying code …" : "Copiando código …",
    "Copied code" : "Código copiado",
    "Could not copy code" : "No se ha podido copiar el código",
    "Delete share link" : "Eliminar enlace compartido",
    "Deleting share link …" : "Eliminando enlace compartido…",
    "{teamDisplayName} (Team)" : "{teamDisplayName} (Equipo)",
    "An error occurred while unsharing the calendar." : "Ocurrió un error al intentar dejar de compartir el calendario.",
    "An error occurred, unable to change the permission of the share." : "Se ha producido un error, no fue posible cambiar los permisos del recurso compartido.",
    "can edit" : "puede editar",
    "Unshare with {displayName}" : "Dejar de compartir con {displayName}",
    "Share with users or groups" : "Compartir con otros usuarios o grupos",
    "No users or groups" : "No hay usuarios ni grupos.",
    "Failed to save calendar name and color" : "Fallo al guardar el nombre del calendario y el color",
    "Calendar name …" : "Nombre de calendario...",
    "Never show me as busy (set this calendar to transparent)" : "Nunca me muestres como ocupado (establecer este calendario como transparente)",
    "Share calendar" : "Compartir calendario",
    "Unshare from me" : "Dejar de compartir conmigo",
    "Save" : "Guardar",
    "Import calendars" : "Importar calendarios",
    "Please select a calendar to import into …" : "Por favor, selecciona un calendario al que importar…",
    "Filename" : "Nombre de archivo",
    "Calendar to import into" : "Calendario en el cual importar",
    "Cancel" : "Cancelar",
    "_Import calendar_::_Import calendars_" : ["Importar calendario","Importar calendarios","Importar calendarios"],
    "Select the default location for attachments" : "Seleccione la ubicación por defecto para los adjuntos",
    "Pick" : "Selecciona",
    "Invalid location selected" : "Se seleccionó una ubicación inválida",
    "Attachments folder successfully saved." : "La carpeta de adjuntos se guardó exitosamente.",
    "Error on saving attachments folder." : "Error al guardar la carpeta de adjuntos.",
    "Default attachments location" : "Ubicación por defecto de los adjuntos",
    "{filename} could not be parsed" : "{filename} no pudo ser analizado",
    "No valid files found, aborting import" : "No se han encontrado archivos válidos, cancelando la importación",
    "_Successfully imported %n event_::_Successfully imported %n events_" : ["Se ha importado con éxito %n evento.","Se han importado con éxito %n eventos.","Se han importado con éxito %n eventos."],
    "Import partially failed. Imported {accepted} out of {total}." : "La importación ha fallado parcialmente. Importados {accepted} sobre {total}.",
    "Automatic" : "Automático",
    "Automatic ({detected})" : "Automático ({detected})",
    "New setting was not saved successfully." : "El nuevo ajuste no ha podido ser guardado correctamente.",
    "Navigation" : "Navegación",
    "Previous period" : "Periodo anterior",
    "Next period" : "Periodo siguiente",
    "Views" : "Vistas",
    "Day view" : "Vista diaria",
    "Week view" : "Vista semanal",
    "Month view" : "Vista mensual",
    "Year view" : "Vista anual",
    "List view" : "Vista de lista",
    "Actions" : "Acciones",
    "Create event" : "Crear evento",
    "Show shortcuts" : "Mostrar atajos",
    "Editor" : "Editor",
    "Close editor" : "Cerrar editor",
    "Save edited event" : "Guardar el evento editado",
    "Delete edited event" : "Borrar el evento editado",
    "Duplicate event" : "Evento duplicado",
    "Shortcut overview" : "Vista general de atajos",
    "or" : "o",
    "Calendar settings" : "Configuración del calendario",
    "At event start" : "Al inicio del evento",
    "No reminder" : "No hay recordatorio",
    "Failed to save default calendar" : "Fallo al guardar el calendario por defecto",
    "CalDAV link copied to clipboard." : "El enlace de CalDAV copiado al portapapeles",
    "CalDAV link could not be copied to clipboard." : "El enlace CalDAV no se puede copiar al portapapeles",
    "Enable birthday calendar" : "Permitir calendario de cumpleaños",
    "Show tasks in calendar" : "Ver tareas en el calendario",
    "Enable simplified editor" : "Activar editor simplificado",
    "Limit the number of events displayed in the monthly view" : "Limita el número de eventos mostrados en la vista mensual",
    "Show weekends" : "Mostrar fines de semana",
    "Show week numbers" : "Mostrar número de semana",
    "Time increments" : "Incrementos de tiempo",
    "Default calendar for incoming invitations" : "Calendario por defecto para aceptar invitaciones",
    "Default reminder" : "Recordatorio predeterminado",
    "Copy primary CalDAV address" : "Copiar dirección primaria de CalDAV",
    "Copy iOS/macOS CalDAV address" : "Copiar la dirección CalDAV iOS/macOS",
    "Personal availability settings" : "Ajustes de disponibilidad personal",
    "Show keyboard shortcuts" : "Mostrar atajos de teclado",
    "Appointment schedule successfully created" : "Horario de citas creado correctamente",
    "Appointment schedule successfully updated" : "Horario de citas actualizado correctamente",
    "_{duration} minute_::_{duration} minutes_" : ["{duration} minuto","{duration} minutos","{duration} minutos"],
    "0 minutes" : "0 minutos",
    "_{duration} hour_::_{duration} hours_" : ["{duration} hora","{duration} horas","{duration} horas"],
    "_{duration} day_::_{duration} days_" : ["{duration} día","{duration} días","{duration} días"],
    "_{duration} week_::_{duration} weeks_" : ["{duration} semana","{duration} semanas","{duration} semanas"],
    "_{duration} month_::_{duration} months_" : ["{duration} mes","{duration} meses","{duration} meses"],
    "_{duration} year_::_{duration} years_" : ["{duration} año","{duration} años","{duration} años"],
    "To configure appointments, add your email address in personal settings." : "Para configurar citas, añade tu dirección de correo en ajustes personales.",
    "Public – shown on the profile page" : "Público - visible en la página de perfil",
    "Private – only accessible via secret link" : "Privado - solamente accesible vía enlace secreto",
    "Appointment schedule saved" : "Horario de citas guardado",
    "Create appointment schedule" : "Horario de citas creado",
    "Edit appointment schedule" : "Editar horario de citas",
    "Update" : "Actualizar",
    "Appointment name" : "Nombre de la cita",
    "Location" : "Ubicación",
    "Create a Talk room" : "Crear una sala de Talk",
    "A unique link will be generated for every booked appointment and sent via the confirmation email" : "Un enlace único será generado por cada cita agendada y será enviado a través del correo electrónico de confirmación",
    "Description" : "Descripción",
    "Visibility" : "Visibilidad",
    "Duration" : "Duración",
    "Increments" : "Incrementos",
    "Additional calendars to check for conflicts" : "Calendarios adicionales sobre los que comprobar conflictos",
    "Pick time ranges where appointments are allowed" : "Elegir rangos de tiempo para permitir citas",
    "to" : "para",
    "Delete slot" : "Eliminar espacio",
    "No times set" : "No hay tiempos definidos",
    "Add" : "Añadir",
    "Monday" : "Lunes",
    "Tuesday" : "Martes",
    "Wednesday" : "Miércoles",
    "Thursday" : "Jueves",
    "Friday" : "Viernes",
    "Saturday" : "Sábado",
    "Sunday" : "Domingo",
    "Weekdays" : "Días de semana",
    "Add time before and after the event" : "Añadir tiempo antes y después del evento",
    "Before the event" : "Antes del evento",
    "After the event" : "Después del evento",
    "Planning restrictions" : "Restricciones de planificación",
    "Minimum time before next available slot" : "Tiempo mínimo antes del próximo espacio disponible",
    "Max slots per day" : "Cantidad de espacios máximos al día",
    "Limit how far in the future appointments can be booked" : "Limitar hasta qué punto en el futuro se pueden reservar citas.",
    "It seems a rate limit has been reached. Please try again later." : "Parece haberse alcanzado un límite de solicitudes. Por favor, inténtelo de nuevo más tarde.",
    "Please confirm your reservation" : "Por favor, confirme su reserva",
    "We sent you an email with details. Please confirm your appointment using the link in the email. You can close this page now." : "Le hemos enviado un correo con los detalles. Por favor, confirme su cita usando el enlace del correo. Ahora puede cerrar esta página.",
    "Your name" : "Su nombre",
    "Your email address" : "Su dirección de correo",
    "Please share anything that will help prepare for our meeting" : "Por favor, comparta cualquier cosa que ayude a prepararnos para nuestra reunión.",
    "Could not book the appointment. Please try again later or contact the organizer." : "No ha sido posible reservar una cita. Por favor, inténtelo más tarde o contacte al organizador.",
    "Back" : "Atrás",
    "Book appointment" : "Reservar cita",
    "Error fetching Talk conversations." : "Error al obtener conversaciones de Talk.",
    "Conversation does not have a valid URL." : "La conversación no tiene una URL válida.",
    "Failed to apply Talk room." : "Error al guardar la sala Talk.",
    "Select a Talk Room" : "Selecciona una sala de Talk",
    "Add Talk conversation" : "Añade una conversación de Talk",
    "Fetching Talk rooms…" : "Obteniendo salas de Talk...",
    "No Talk room available" : "No hay ninguna sala de Talk disponible",
    "Create a new conversation" : "Crear una conversación nueva",
    "Select conversation" : "Selecciona conversación",
    "on" : "activo",
    "at" : "a",
    "before at" : "antes de las",
    "Notification" : "Notificación",
    "Email" : "Correo electrónico",
    "Audio notification" : "Notificación de audio",
    "Other notification" : "Otras notificaciones",
    "Relative to event" : "Relativo al evento",
    "On date" : "en fecha",
    "Edit time" : "Hora de edición",
    "Save time" : "Guardar hora",
    "Remove reminder" : "Eliminar recordatorio",
    "Add reminder" : "Añadir recordatorio",
    "seconds" : "seconds",
    "minutes" : "minutos",
    "hours" : "horas",
    "days" : "días",
    "weeks" : "semanas",
    "Choose a file to add as attachment" : "Escoja un archivo para adjuntar",
    "Choose a file to share as a link" : "Escoja un archivo para compartir como enlace",
    "Attachment {name} already exist!" : "¡El adjunto {name} ya existe!",
    "Could not upload attachment(s)" : "No se pudo subir el/los adjunto(s)",
    "You are about to navigate to {host}. Are you sure to proceed? Link: {link}" : "Estás a punto de navegar a {host}. ¿Estás seguro? Enlace: {link}",
    "Proceed" : "Proceder",
    "No attachments" : "Sin adjuntos",
    "Add from Files" : "Añadir desde Archivos",
    "Upload from device" : "Subir desde dispositivo",
    "Delete file" : "Eliminar archivo",
    "Confirmation" : "Confirmación",
    "_{count} attachment_::_{count} attachments_" : ["{count} adjunto","{count} adjuntos","{count} adjuntos"],
    "Suggested" : "Sugerido",
    "Available" : "Disponible",
    "Invitation accepted" : "Invitación aceptada",
    "Accepted {organizerName}'s invitation" : "Se aceptó la invitación de {organizerName}",
    "Participation marked as tentative" : "Participación marcada como provisional",
    "Invitation is delegated" : "Se ha delegado la invitación",
    "Not available" : "No disponible",
    "Invitation declined" : "Invitación rechazada",
    "Declined {organizerName}'s invitation" : "Se ha rechazado la invitación de {organizerName}",
    "Availability will be checked" : "La disponibilidad se comprobará",
    "Invitation will be sent" : "La invitación será enviada",
    "Failed to check availability" : "Fallo al comprobar la disponibilidad",
    "Failed to deliver invitation" : "Fallo al entregar la invitación",
    "Awaiting response" : "Esperando respuesta",
    "Checking availability" : "Comprobando disponibilidad",
    "Has not responded to {organizerName}'s invitation yet" : "Todavía no ha respondido a la invitación de {organizerName}.",
    "chairperson" : "moderador",
    "required participant" : "participante requerido",
    "non-participant" : "no es participante",
    "optional participant" : "participante opcional",
    "{organizer} (organizer)" : "{organizer} (organizador)",
    "{attendee} ({role})" : "{attendee} ({role})",
    "Availability of attendees, resources and rooms" : "Disponibilidad de asistentes, recursos y habitaciones",
    "Suggestion accepted" : "Sugerencia aceptada",
    "Legend" : "Leyenda",
    "Out of office" : "Fuera de la oficina",
    "Attendees:" : "Asistentes:",
    "Done" : "Listo",
    "Search room" : "Buscar sala",
    "Room name" : "Nombre de la sala",
    "Check room availability" : "Comprueba la disponibilidad de la sala",
    "Free" : "Libre",
    "Busy (tentative)" : "Ocupado (provisional)",
    "Busy" : "Ocupado",
    "Unknown" : "Desconocido",
    "Find a time" : "Buscar una hora",
    "The invitation has been accepted successfully." : "La invitación se ha aceptado con éxito.",
    "Failed to accept the invitation." : "Fallo al aceptar la invitación.",
    "The invitation has been declined successfully." : "La invitación se ha declinado con éxito.",
    "Failed to decline the invitation." : "Fallo al declinar la invitación.",
    "Your participation has been marked as tentative." : "Se ha marcado tu participación como provisional.",
    "Failed to set the participation status to tentative." : "Fallo al marcar el estado de participación como provisional.",
    "Accept" : "Aceptar",
    "Decline" : "Declinar",
    "Tentative" : "Pendiente",
    "No attendees yet" : "Aún no hay asistentes",
    "{invitedCount} invited, {confirmedCount} confirmed" : "{invitedCount} invitados, {confirmedCount} confirmados",
    "Successfully appended link to talk room to location." : "Se ha añadido correctamente el enlace a la sala de conversación.",
    "Successfully appended link to talk room to description." : "Enlace agregado con éxito en la descripción a la sala de conversación.",
    "Error creating Talk room" : "Error al crear la sala de conversación",
    "Attendees" : "Asistentes",
    "_%n more guest_::_%n more guests_" : ["%n invitado mas","%n mas invitados","%n mas invitados"],
    "Remove group" : "Eliminar grupo",
    "Remove attendee" : "Eliminar asistente",
    "Request reply" : "Solicitar respuesta",
    "Chairperson" : "Presidente/a",
    "Required participant" : "Participante requerido",
    "Optional participant" : "Participante opcional",
    "Non-participant" : "No participa",
    "_%n member_::_%n members_" : ["%n miembro","%n miembros","%n miembros"],
    "No match found" : "No se ha encontrado ningún resultado",
    "Note that members of circles get invited but are not synced yet." : "Tenga en cuenta que los miembros de los círculos serán invitados pero aún no están sincronizados.",
    "Note that members of contact groups get invited but are not synced yet." : "Ten en cuenta que los miembros de los grupos de contactos son invitados pero aún no están sincronizados.",
    "(organizer)" : "(organizador)",
    "Make {label} the organizer" : "Haz a {label} el organizador",
    "Make {label} the organizer and attend" : "Haz a {label} el organizador y asiste tú",
    "To send out invitations and handle responses, [linkopen]add your email address in personal settings[linkclose]." : "Para enviar invitaciones y gestionar las respuestas,  [linkopen]añade tu dirección email en los ajustes personales[linkclose].",
    "Remove color" : "Quitar color",
    "Event title" : "Título del evento",
    "Cannot modify all-day setting for events that are part of a recurrence-set." : "No se puede modificar el ajuste de todo el día en eventos que son parte de una serie recurrente.",
    "From" : "De",
    "To" : "A",
    "Repeat" : "Repetir",
    "_time_::_times_" : ["vez","veces","veces"],
    "never" : "nunca",
    "on date" : "en fecha",
    "after" : "después de",
    "End repeat" : "Finalizar repetición",
    "Select to end repeat" : "Seleccionar para finalizar la repetición",
    "This event is the recurrence-exception of a recurrence-set. You cannot add a recurrence-rule to it." : "Este evento es la excepción a la serie recurrente. No le puedes añadir una regla recurrente.",
    "first" : "primero",
    "Changes to the recurrence-rule will only apply to this and all future occurrences." : "Los cambios en la regla de recurrencia solo se aplicarán a este y a todos los sucesos futuros.",
    "Repeat every" : "Repetir cada",
    "By day of the month" : "Por día del mes",
    "On the" : "En el",
    "_day_::_days_" : ["día","días","días"],
    "_week_::_weeks_" : ["semana","semanas","semanas"],
    "_month_::_months_" : ["mes","meses","meses"],
    "_year_::_years_" : ["año","años","años"],
    "weekday" : "día laborable",
    "weekend day" : "día de fin de semana",
    "Does not repeat" : "No repetir",
    "The recurrence definition of this event is not fully supported by Nextcloud. If you edit the recurrence-options, certain recurrences may be lost." : "Nextcloud no admite totalmente la definición de recurrencia de este evento. Si edita las opciones de recurrencia, ciertas repeticiones pueden perderse.",
    "No rooms or resources yet" : "Aún no hay salas ni recursos",
    "Resources" : "Recursos",
    "_{seatingCapacity} seat_::_{seatingCapacity} seats_" : ["{seatingCapacity} asiento","{seatingCapacity} asientos","{seatingCapacity} asientos"],
    "Add resource" : "Añade recurso",
    "Has a projector" : "Tiene un proyector",
    "Has a whiteboard" : "Tiene una pizarra",
    "Wheelchair accessible" : "Accesible en silla de ruedas",
    "Remove resource" : "Quitar recurso",
    "Search for resources or rooms" : "Buscar recursos o salas",
    "available" : "disponible",
    "unavailable" : "no disponible",
    "Show all rooms" : "Muestra todas las salas",
    "Projector" : "Proyector",
    "Whiteboard" : "Pizarra blanca",
    "Room type" : "Tipo de sala",
    "Any" : "Cualquiera",
    "Minimum seating capacity" : "Capacidad mínima de los asientos",
    "More details" : "Más detalles",
    "Update this and all future" : "Actualiza esto y todo futuro",
    "Update this occurrence" : "Actualiza esta ocurrencia",
    "Public calendar does not exist" : "Este calendario público no existe",
    "Maybe the share was deleted or has expired?" : "¿Puede ser que el recurso compartido haya sido borrado o haya caducado?",
    "from {formattedDate}" : "desde {formattedDate}",
    "to {formattedDate}" : "hasta {formattedDate}",
    "on {formattedDate}" : "en {formattedDate}",
    "from {formattedDate} at {formattedTime}" : "desde {formattedDate} a las {formattedTime}",
    "to {formattedDate} at {formattedTime}" : "hasta {formattedDate} a las {formattedTime}",
    "on {formattedDate} at {formattedTime}" : "en {formattedDate} a las {formattedTime}",
    "{formattedDate} at {formattedTime}" : "{formattedDate} a las {formattedTime}",
    "Please enter a valid date" : "Por favor especifique una fecha  válida",
    "Please enter a valid date and time" : "Por favor especifique valores correctos de fecha y hora",
    "Select a time zone" : "Selecciona una zona horaria",
    "Please select a time zone:" : "Por favor seleccione una zona horaria:",
    "Pick a time" : "Elija una hora",
    "Pick a date" : "Elija una fecha",
    "Type to search time zone" : "Escribe para buscar la zona horaria",
    "Global" : "Global",
    "Holidays in {region}" : "Días feriados en {region}",
    "An error occurred, unable to read public calendars." : "Ocurrió un error, no se pueden leer los calendarios públicos.",
    "An error occurred, unable to subscribe to calendar." : "Ocurrió un error, no fue posible suscribirse al calendario.",
    "Public holiday calendars" : "Calendarios de días feriados públicos",
    "Public calendars" : "Calendarios públicos",
    "No valid public calendars configured" : "No hay calendarios públicos válidos configurados",
    "Speak to the server administrator to resolve this issue." : "Converse con el administrador del servidor para resolver el problema",
    "Public holiday calendars are provided by Thunderbird. Calendar data will be downloaded from {website}" : "Los calendarios de días feriados públicos son provistos por Thunderbird. Los datos del calendario serán descargados desde {website}",
    "These public calendars are suggested by the sever administrator. Calendar data will be downloaded from the respective website." : "Estos calendarios públicos son sugeridos por el administrador del servidor. Los datos del calendario se descargarán desde el sitio web correspondiente.",
    "By {authors}" : "Por {authors}",
    "Subscribed" : "Suscrito",
    "Subscribe" : "Suscribirse",
    "Could not fetch slots" : "No se pudieron obtener los intervalos de tiempo",
    "Select a date" : "Seleccione una fecha",
    "Select slot" : "Seleccionar hora",
    "No slots available" : "No hay horas disponibles",
    "The slot for your appointment has been confirmed" : "La hora de tu cita ha sido confirmada",
    "Appointment Details:" : "Detalles de la cita:",
    "Time:" : "Hora:",
    "Booked for:" : "Reservado para:",
    "Thank you. Your booking from {startDate} to {endDate} has been confirmed." : "Gracias. Tu reserva de {startDate} a {endDate} ha sido confirmada.",
    "Book another appointment:" : "Reservar otra cita:",
    "See all available slots" : "Ver todos los huecos disponibles",
    "The slot for your appointment from {startDate} to {endDate} is not available any more." : "La hora de tu cita de {startDate} a  {endDate} ya no está disponible.",
    "Please book a different slot:" : "Por favor, reserva otra hora distinta:",
    "Book an appointment with {name}" : "Reservar una cita con {name}",
    "No public appointments found for {name}" : "No se han encontrado citas públicas para {name}",
    "Personal" : "Personal",
    "The automatic time zone detection determined your time zone to be UTC.\nThis is most likely the result of security measures of your web browser.\nPlease set your time zone manually in the calendar settings." : "La detección automática de la zona horaria determinó que tu zona horaria sea UTC. Esto es probablemente el resultado de las medidas de seguridad de su navegador web. Por favor establezca su zona horaria manualmente en la configuración del calendario. ",
    "Your configured time zone ({timezoneId}) was not found. Falling back to UTC.\nPlease change your time zone in the settings and report this issue." : "No se ha encontrado la zona horaria configurada ({timezoneId}). Volviendo a UTC.\nPor favor, cambia tu zona horaria en la configuración e informa de este problema.",
    "Availability of {displayName}" : "Disponibilidad de {displayName}",
    "Edit event" : "Editar evento",
    "Event does not exist" : "el evento no existe",
    "Duplicate" : "Duplicar",
    "Delete this occurrence" : "Eliminar esta ocurrencia",
    "Delete this and all future" : "Eliminar este y los futuros",
    "All day" : "Todo el día",
    "Managing shared access" : "Administrando el acceso compartido",
    "Deny access" : "Denegar acceso",
    "Invite" : "Invitar",
    "_User requires access to your file_::_Users require access to your file_" : ["El usuario requieren acceso a su archivo","Los usuarios requieren acceso a su archivo","Los usuarios requieren acceso a su archivo"],
    "_Attachment requires shared access_::_Attachments requiring shared access_" : ["Adjunto que requiere acceso compartido","Adjuntos que requieren acceso compartido","Adjuntos que requieren acceso compartido"],
    "Untitled event" : "Evento sin título",
    "Close" : "Cerrar",
    "Subscribe to {name}" : "Subscribir a {name}",
    "Export {name}" : "Exportar {name}",
    "Show availability" : "Mostrar disponibilidad",
    "Anniversary" : "Aniversario",
    "Appointment" : "Cita",
    "Business" : "Empresa",
    "Education" : "Educación",
    "Holiday" : "Vacaciones",
    "Meeting" : "Reunión",
    "Miscellaneous" : "Varios",
    "Non-working hours" : "Horario no laborable",
    "Not in office" : "Fuera de la oficina",
    "Phone call" : "Llamad de teléfono",
    "Sick day" : "Estoy enfermo",
    "Special occasion" : "Ocasión especial",
    "Travel" : "Viaje",
    "Vacation" : "Vacaciones",
    "Midnight on the day the event starts" : "Medianoche del día en el que comienza el evento",
    "_%n day before the event at {formattedHourMinute}_::_%n days before the event at {formattedHourMinute}_" : ["%n día antes del evento, a las {formattedHourMinute}","%n días antes del evento, a las {formattedHourMinute}","%n días antes del evento, a las {formattedHourMinute}"],
    "_%n week before the event at {formattedHourMinute}_::_%n weeks before the event at {formattedHourMinute}_" : ["%n semana antes del evento, a las {formattedHourMinute}","%n semanas antes del evento, a las {formattedHourMinute}","%n semanas antes del evento, a las {formattedHourMinute}"],
    "on the day of the event at {formattedHourMinute}" : "en el día del evento, a las {formattedHourMinute}",
    "at the event's start" : "al comienzo del evento",
    "at the event's end" : "al final del evento",
    "{time} before the event starts" : "{time} antes de que comience el evento",
    "{time} before the event ends" : "{time} antes de que termine el evento",
    "{time} after the event starts" : "{time} después de que comience el evento",
    "{time} after the event ends" : "{time} después de que termine el evento",
    "on {time}" : "a las {time}",
    "on {time} ({timezoneId})" : "a las {time} ({timezoneld})",
    "Week {number} of {year}" : "Semana {number} de {year}",
    "Daily" : "Diariamente",
    "Weekly" : "Semanalmente",
    "Monthly" : "Mensualmente",
    "Yearly" : "Anualmente",
    "_Every %n day_::_Every %n days_" : ["Cada %n día","Cada %n días","Cada %n días"],
    "_Every %n week_::_Every %n weeks_" : ["Cada %n semana","Cada %n semanas","Cada %n semanas"],
    "_Every %n month_::_Every %n months_" : ["Cada %n mes","Cada %n meses","Cada %n meses"],
    "_Every %n year_::_Every %n years_" : ["Cada %n año","Cada %n años","Cada %n años"],
    "_on {weekday}_::_on {weekdays}_" : ["en {weekday}","en {weekdays}","en {weekdays}"],
    "_on day {dayOfMonthList}_::_on days {dayOfMonthList}_" : ["en día {dayOfMonthList}","en los días {dayOfMonthList}","en los días {dayOfMonthList}"],
    "on the {ordinalNumber} {byDaySet}" : "en el {ordinalNumber} {byDaySet}",
    "in {monthNames} on the {ordinalNumber} {byDaySet}" : "el {ordinalNumber} {byDaySet} de {monthNames} ",
    "until {untilDate}" : "hasta {untilDate}",
    "_%n time_::_%n times_" : ["%n vez","%n veces","%n veces"],
    "second" : "segundo",
    "third" : "tercero",
    "fourth" : "cuarto",
    "fifth" : "quinto",
    "second to last" : "penúltimo",
    "last" : "último",
    "Untitled task" : "Tarea sin título",
    "Please ask your administrator to enable the Tasks App." : "Por favor, solicite a su administrador que permita la aplicación de tareas.",
    "W" : "S",
    "%n more" : "%n más",
    "No events to display" : "No hay eventos que mostrar",
    "_+%n more_::_+%n more_" : ["+%n más","+%n más","+%n más"],
    "No events" : "No hay eventos",
    "Create a new event or change the visible time-range" : "Crea un evento nuevo o cambia el rango de horas visibles",
    "Failed to save event" : "Fallo al guardar evento",
    "It might have been deleted, or there was a typo in a link" : "Puede haber sido borrado, o había una errata en el enlace",
    "It might have been deleted, or there was a typo in the link" : "Puede haber sido borrado, o había una errata en el enlace",
    "Meeting room" : "Sala de reuniones",
    "Lecture hall" : "Sala de conferencias",
    "Seminar room" : "Sala de seminario",
    "Other" : "Otro",
    "When shared show" : "Al compartir, mostrar",
    "When shared show full event" : "Al compartir, mostrar el evento completo",
    "When shared show only busy" : "Al compartir, mostrar solo ocupado",
    "When shared hide this event" : "Al compartir, ocultar este evento",
    "The visibility of this event in shared calendars." : "Visibilidad de este evento en calendarios compartidos",
    "Add a location" : "Añadir ubicación",
    "Add a description\n\n- What is this meeting about\n- Agenda items\n- Anything participants need to prepare" : "Añade una descripción\n\n- ¿De qué va esta reunión?\n- Orden del día\n- Algo que se tengan que preparar los participantes",
    "Status" : "Estado",
    "Confirmed" : "Confirmado",
    "Canceled" : "Cancelado",
    "Confirmation about the overall status of the event." : "Confirmación acerca del estado general del evento.",
    "Show as" : "Mostrar como",
    "Take this event into account when calculating free-busy information." : "Tome este evento en consideración cuando calcule la información acerca de libre-ocupado.",
    "Categories" : "Categorías",
    "Categories help you to structure and organize your events." : "Las categorías le ayudan a estructurar y organizar sus eventos.",
    "Search or add categories" : "Buscar o añadir categorías",
    "Add this as a new category" : "Añadir esto como categoría nueva",
    "Custom color" : "Colores personalizados",
    "Special color of this event. Overrides the calendar-color." : "Color especial de este evento. Reemplazará al color de calendario.",
    "Error while sharing file" : "Error al compartir archivo",
    "Error while sharing file with user" : "Error al compartir el archivo con el usuario",
    "Error creating a folder {folder}" : "Error creando la carpeta {folder}",
    "Attachment {fileName} already exists!" : "¡El adjunto {fileName} ya existe!",
    "An error occurred during getting file information" : "Ocurrió un error al obtener la información del archivo",
    "Talk conversation for event" : "Conversación de Talk para el evento",
    "An error occurred, unable to delete the calendar." : "Se ha producido un error, no se ha podido borrar el calendario.",
    "Imported {filename}" : "Importado {filename}",
    "This is an event reminder." : "Esto es un recordatorio de evento.",
    "Error while parsing a PROPFIND error" : "Error al analizar un error PROPFIND",
    "Appointment not found" : "Cita no encontrada",
    "User not found" : "Usuario no encontrado",
    "Reminder" : "Recordatorio",
    "+ Add reminder" : "+ Añadir recordatorio",
    "Select automatic slot" : "Seleccione un espacio de tiempo automático",
    "with" : "con",
    "Available times:" : "Horas disponibles:",
    "Suggestions" : "Sugerencias",
    "Details" : "Detalles"
},
"nplurals=3; plural=n == 1 ? 0 : n != 0 && n % 1000000 == 0 ? 1 : 2;");
